@@ -1,12 +1,14 @@
 import io
 import collections
 import logging
+import posixpath
 import pandas as pd
 import time
 import csv
 from airflow.operators.python import PythonOperator
 
 from data_product_sdk.cortex_airflow.data_platform.utils.sid_utils import process_date_columns, reorder_df_to_sid, upload_file, get_sid_token
+from data_product_sdk.cortex_databricks.data_platform.aws_utils import S3
 
 SID_MAX_ROWS = 10000000
 log = logging.getLogger(__name__)
@@ -14,7 +16,7 @@ log = logging.getLogger(__name__)
 
 class SidOperator(PythonOperator):
     def __init__(self, task_id, cube_id, platform_url: str, username: str, password: str, python_callable, op_kwargs=None, ignore_empty_dataframe=False, sleep_between_chunks=30,
-                 sid_chunksize=SID_MAX_ROWS, date_columns: list = None, pandas_kwargs: dict = None, retries=2, **kwargs) -> None:
+                 sid_chunksize=SID_MAX_ROWS, date_columns: list = None, pandas_kwargs: dict = None, retries=2, replicate_to_s3=None, **kwargs) -> None:
         """
         Operator that expects a python_callable that returns or yields a pandas Dataframe to process and insert the corresponding Dataframe into a csv to SID
 
@@ -31,6 +33,7 @@ class SidOperator(PythonOperator):
         :param sid_chunksize: max number of rows per chunk to send to SID
         :param date_columns: list of columns containing the name of the columns that are date type to be pre-processed (SID have specific requirements for date types)
         :param pandas_kwargs: dictionary containing the parameters to be forwarded to pandas 'to_csv' method
+        :param replicate_to_s3: s3 path to replicate the dataframe to be uploaded to SID
         :param kwargs: all kwargs will be forwarded to the PythonOperator as parameters
         """
         if op_kwargs is None:
@@ -50,6 +53,7 @@ class SidOperator(PythonOperator):
         self.sleep_between_chunks = sleep_between_chunks
         self.date_columns = date_columns
         self.sid_chunksize = sid_chunksize
+        self.replicate_to_s3 = replicate_to_s3
 
     def process_date_columns(self, df):
         process_date_columns(df, date_columns=self.date_columns)
@@ -76,6 +80,13 @@ class SidOperator(PythonOperator):
                                    file_like_object=string_buffer
                                    )
 
+        if self.replicate_to_s3:
+            string_buffer.seek(0)
+            s3_bucket, s3_key = S3.get_bucket_key_from_s3_url(s3_url=self.replicate_to_s3)
+            s3_key = posixpath.join(s3_key, f'{execution_id}.csv')
+            s3_client = S3(bucket_name=s3_bucket)
+            s3_client.put_object(data=string_buffer, s3_key=s3_key)
+
         return execution_id
 
     def __upload_pandas_df_to_sid(self, df, pandas_kwargs=None):
@@ -135,3 +146,4 @@ class SidOperator(PythonOperator):
         context['task_instance'].xcom_push(key='execution_ids', value=execution_ids)
         context['task_instance'].xcom_push(key='platform_url', value=self.platform_url)
         context['task_instance'].xcom_push(key='credentials', value={'username': self.username, 'password': self.password})
+
