@@ -41,10 +41,12 @@ LANDING_BUCKET = f"cortex-data-platform-landing-area-{ENVIRONMENT}"
 BRONZE_BUCKET = f"cortex-databricks-bronze-{ENVIRONMENT}"
 SILVER_BUCKET = f"cortex-databricks-silver-{ENVIRONMENT}"
 GOLD_BUCKET = f"cortex-databricks-gold-{ENVIRONMENT}"
+DIAMOND_BUCKET = f"cortex-databricks-diamond-{ENVIRONMENT}"
 
 BRONZE_DB_NAME = f"cortex_databricks_bronze_{ENVIRONMENT}"
 SILVER_DB_NAME = f"cortex_databricks_silver_{ENVIRONMENT}"
 GOLD_DB_NAME = f"cortex_databricks_gold_{ENVIRONMENT}"
+DIAMOND_DB_NAME = f"cortex_databricks_diamond_{ENVIRONMENT}"
 
 
 def __verify_parameters(function):
@@ -795,6 +797,107 @@ def silver_to_gold(
             df=df, data_pack_name=data_pack_name, dataset_name=dataset_name, layer="gold"
         )
 
+@__verify_parameters
+def gold_to_diamond(
+    input_table_name,
+    data_pack_name,
+    dataset_name,
+    insert_mode,
+    input_db_name=None,
+    output_db_name=None,
+    partition_columns=None,
+    spark=None,
+    write_options: dict = None,
+    processing_function=None,
+    processing_function_args=None,
+    processing_function_kwargs=None,
+    profiling=False,
+    sort_fields: list = None,
+    upsert_fields: list = None,
+    reset_checkpoint=False,
+    catalog_name=None,
+    where=None,
+    tbl_properties=None,
+):
+    if spark is None:
+        spark = get_spark_session(app_name=dataset_name)
+    if partition_columns is None:
+        partition_columns = list()
+    if upsert_fields is None:
+        upsert_fields = ["cortex_id"]
+    if input_db_name is None:
+        input_db_name = GOLD_DB_NAME
+    if output_db_name is None:
+        output_db_name = DIAMOND_DB_NAME
+
+    if catalog_name is None:
+        catalog_name = "hive_metastore"
+
+    if os.getenv("ENVIRONMENT") != "LOCAL":
+        spark.sql(f"USE CATALOG {catalog_name}")
+
+    input_db_name = f"{catalog_name}.{input_db_name}"
+    output_db_name = f"{catalog_name}.{output_db_name}"
+
+    if sort_fields is None:
+        sort_fields = get_table_partitions(
+            spark=spark, db_name=input_db_name, table_name=input_table_name
+        )
+    if reset_checkpoint:
+        reset_autoloader_checkpoint(
+            bucket_name=DIAMOND_BUCKET,
+            data_pack_name=data_pack_name,
+            dataset_name=dataset_name,
+            input_table_name=input_table_name,
+        )
+    if insert_mode is None:
+        insert_mode = "append"
+
+    df = read_table(
+        spark, db_name=input_db_name, table_name=input_table_name, where=where
+    )
+    df = apply_processing_function(
+        df=df,
+        func=processing_function,
+        func_args=processing_function_args,
+        func_kwargs=processing_function_kwargs,
+    )
+
+    checkpoint_location = build_checkpoint_path(
+        bucket_name=DIAMOND_BUCKET,
+        data_pack_name=data_pack_name,
+        dataset_name=dataset_name,
+        input_table_name=input_table_name,
+    )
+    stream = write_table(
+        df,
+        checkpoint_location=checkpoint_location,
+        db_name=output_db_name,
+        table_name=dataset_name,
+        insert_mode=insert_mode,
+        spark=spark,
+        partition_columns=partition_columns,
+        write_options=write_options,
+        sort_fields=sort_fields,
+        upsert_fields=upsert_fields,
+    )
+
+    output_db_table = f"{output_db_name}.{dataset_name}"
+
+    if catalog_name != "hive_metastore":
+        set_owner_to(spark, output_db_table, "data-production")
+
+    if tbl_properties:
+        set_tbl_properties(spark, output_db_table, tbl_properties)
+
+    if profiling:
+        stream.awaitTermination()
+        df = spark.read.table(output_db_table)
+        apply_profiling(
+            df=df, data_pack_name=data_pack_name, dataset_name=dataset_name, layer="diamond"
+        )
+
+    return True
 
 def gold_to_kafka(
     input_table_name,
